@@ -1,7 +1,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2020 David R. MacIver
+# Most of this work is copyright (C) 2013-2021 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -13,7 +13,6 @@
 #
 # END HEADER
 
-
 class IntervalSet:
     def __init__(self, intervals):
         self.intervals = tuple(intervals)
@@ -33,7 +32,7 @@ class IntervalSet:
         if i < 0:
             i = self.size + i
         if i < 0 or i >= self.size:
-            raise IndexError("Invalid index %d for [0, %d)" % (i, self.size))
+            raise IndexError(f"Invalid index {i} for [0, {self.size})")
         # Want j = maximal such that offsets[j] <= i
 
         j = len(self.intervals) - 1
@@ -55,17 +54,17 @@ class IntervalSet:
         return r
 
     def __repr__(self):
-        return "IntervalSet(%r)" % (self.intervals,)
+        return f"IntervalSet({self.intervals!r})"
 
     def index(self, value):
         for offset, (u, v) in zip(self.offsets, self.intervals):
             if u == value:
                 return offset
             elif u > value:
-                raise ValueError("%d is not in list" % (value,))
+                raise ValueError(f"{value} is not in list")
             if value <= v:
                 return offset + (value - u)
-        raise ValueError("%d is not in list" % (value,))
+        raise ValueError(f"{value} is not in list")
 
     def index_above(self, value):
         for offset, (u, v) in zip(self.offsets, self.intervals):
